from typing import Any

def manager_repr(value: Any) -> str: ...
def smart_repr(value: Any) -> str: ...
def field_repr(field: Any, force_many: bool = ...) -> str: ...
def serializer_repr(serializer: Any, indent: Any, force_many: Any | None = ...) -> str: ...
def list_repr(serializer: Any, indent: Any) -> str: ...
